@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //*************************************************************************
 //
-// Copyright 2000-2015 by Wilson Snyder.  This program is free software;
+// Copyright 2000-2016 by Wilson Snyder.  This program is free software;
 // you can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 //
@@ -38,12 +38,14 @@ VParseGrammar*	VParseGrammar::s_grammarp = NULL;
 
 //*************************************************************************
 
-VParse::VParse(VFileLine* filelinep, av* symsp, bool sigParser, bool useUnreadbackFlag)
+VParse::VParse(VFileLine* filelinep, av* symsp,
+	       bool sigParser, bool useUnreadbackFlag, bool useProtected)
     : m_syms(filelinep, symsp)
 {
     m_inFilelinep = filelinep;
     m_sigParser = sigParser;
     m_useUnreadback = useUnreadbackFlag;
+    m_useProtected = useProtected;
     m_debug = 0;
     m_lexp = new VParseLex(this);
     m_grammarp = new VParseGrammar(this);
